==> scalarx_2.10-0.2.3-JS.jar: rx/core/Dynamic$.js <==
/** @constructor */
ScalaJS.c.rx_core_Dynamic$ = (function() {
  ScalaJS.c.java_lang_Object.call(this);
  this.enclosing$1 = null
});
ScalaJS.c.rx_core_Dynamic$.prototype = new ScalaJS.inheritable.java_lang_Object();
ScalaJS.c.rx_core_Dynamic$.prototype.constructor = ScalaJS.c.rx_core_Dynamic$;
ScalaJS.c.rx_core_Dynamic$.prototype.enclosing__Lscala_util_DynamicVariable = (function() {
  return this.enclosing$1
});
ScalaJS.c.rx_core_Dynamic$.prototype.$$lessinit$greater$default$2__T = (function() {
  return ""
});
ScalaJS.c.rx_core_Dynamic$.prototype.init___ = (function() {
  ScalaJS.c.java_lang_Object.prototype.init___.call(this);
  ScalaJS.moduleInstances.rx_core_Dynamic = this;
  this.enclosing$1 = new ScalaJS.c.scala_util_DynamicVariable().init___O(ScalaJS.modules.scala_None());
  return this
});
ScalaJS.c.rx_core_Dynamic$.prototype.enclosing__ = (function() {
  return this.enclosing__Lscala_util_DynamicVariable()
});
/** @constructor */
ScalaJS.inheritable.rx_core_Dynamic$ = (function() {
  /*<skip>*/
});
ScalaJS.inheritable.rx_core_Dynamic$.prototype = ScalaJS.c.rx_core_Dynamic$.prototype;
ScalaJS.is.rx_core_Dynamic$ = (function(obj) {
  return (!(!((obj && obj.$classData) && obj.$classData.ancestors.rx_core_Dynamic$)))
});
ScalaJS.as.rx_core_Dynamic$ = (function(obj) {
  if ((ScalaJS.is.rx_core_Dynamic$(obj) || (obj === null))) {
    return obj
  } else {
    ScalaJS.throwClassCastException(obj, "rx.core.Dynamic")
  }
});
ScalaJS.isArrayOf.rx_core_Dynamic$ = (function(obj, depth) {
  return (!(!(((obj && obj.$classData) && (obj.$classData.arrayDepth === depth)) && obj.$classData.arrayBase.ancestors.rx_core_Dynamic$)))
});
ScalaJS.asArrayOf.rx_core_Dynamic$ = (function(obj, depth) {
  if ((ScalaJS.isArrayOf.rx_core_Dynamic$(obj, depth) || (obj === null))) {
    return obj
  } else {
    ScalaJS.throwArrayCastException(obj, "Lrx.core.Dynamic;", depth)
  }
});
ScalaJS.data.rx_core_Dynamic$ = new ScalaJS.ClassTypeData({
  rx_core_Dynamic$: 0
}, false, "rx.core.Dynamic$", ScalaJS.data.java_lang_Object, {
  rx_core_Dynamic$: 1,
  java_lang_Object: 1
});
ScalaJS.c.rx_core_Dynamic$.prototype.$classData = ScalaJS.data.rx_core_Dynamic$;
ScalaJS.moduleInstances.rx_core_Dynamic = undefined;
ScalaJS.modules.rx_core_Dynamic = (function() {
  if ((!ScalaJS.moduleInstances.rx_core_Dynamic)) {
    ScalaJS.moduleInstances.rx_core_Dynamic = new ScalaJS.c.rx_core_Dynamic$().init___()
  };
  return ScalaJS.moduleInstances.rx_core_Dynamic
});
//@ sourceMappingURL=Dynamic$.js.map

==> scalarx_2.10-0.2.4-JS.jar: rx/core/Dynamic$.js <==
/** @constructor */
ScalaJS.c.rx_core_Dynamic$ = (function() {
  ScalaJS.c.java_lang_Object.call(this);
  this.enclosing$1 = null
});
ScalaJS.c.rx_core_Dynamic$.prototype = new ScalaJS.inheritable.java_lang_Object();
ScalaJS.c.rx_core_Dynamic$.prototype.constructor = ScalaJS.c.rx_core_Dynamic$;
ScalaJS.c.rx_core_Dynamic$.prototype.enclosing__Lscala_util_DynamicVariable = (function() {
  return this.enclosing$1
});
ScalaJS.c.rx_core_Dynamic$.prototype.$$lessinit$greater$default$2__T = (function() {
  return ""
});
ScalaJS.c.rx_core_Dynamic$.prototype.init___ = (function() {
  ScalaJS.c.java_lang_Object.prototype.init___.call(this);
  ScalaJS.moduleInstances.rx_core_Dynamic = this;
  this.enclosing$1 = new ScalaJS.c.scala_util_DynamicVariable().init___O(ScalaJS.modules.scala_None());
  return this
});
ScalaJS.c.rx_core_Dynamic$.prototype.$$lessinit$greater$default$2__ = (function() {
  return this.$$lessinit$greater$default$2__T()
});
ScalaJS.c.rx_core_Dynamic$.prototype.enclosing__ = (function() {
  return this.enclosing__Lscala_util_DynamicVariable()
});
/** @constructor */
ScalaJS.inheritable.rx_core_Dynamic$ = (function() {
  /*<skip>*/
});
ScalaJS.inheritable.rx_core_Dynamic$.prototype = ScalaJS.c.rx_core_Dynamic$.prototype;
ScalaJS.is.rx_core_Dynamic$ = (function(obj) {
  return (!(!((obj && obj.$classData) && obj.$classData.ancestors.rx_core_Dynamic$)))
});
ScalaJS.as.rx_core_Dynamic$ = (function(obj) {
  if ((ScalaJS.is.rx_core_Dynamic$(obj) || (obj === null))) {
    return obj
  } else {
    ScalaJS.throwClassCastException(obj, "rx.core.Dynamic")
  }
});
ScalaJS.isArrayOf.rx_core_Dynamic$ = (function(obj, depth) {
  return (!(!(((obj && obj.$classData) && (obj.$classData.arrayDepth === depth)) && obj.$classData.arrayBase.ancestors.rx_core_Dynamic$)))
});
ScalaJS.asArrayOf.rx_core_Dynamic$ = (function(obj, depth) {
  if ((ScalaJS.isArrayOf.rx_core_Dynamic$(obj, depth) || (obj === null))) {
    return obj
  } else {
    ScalaJS.throwArrayCastException(obj, "Lrx.core.Dynamic;", depth)
  }
});
ScalaJS.data.rx_core_Dynamic$ = new ScalaJS.ClassTypeData({
  rx_core_Dynamic$: 0
}, false, "rx.core.Dynamic$", ScalaJS.data.java_lang_Object, {
  rx_core_Dynamic$: 1,
  java_lang_Object: 1
});
ScalaJS.c.rx_core_Dynamic$.prototype.$classData = ScalaJS.data.rx_core_Dynamic$;
ScalaJS.moduleInstances.rx_core_Dynamic = undefined;
ScalaJS.modules.rx_core_Dynamic = (function() {
  if ((!ScalaJS.moduleInstances.rx_core_Dynamic)) {
    ScalaJS.moduleInstances.rx_core_Dynamic = new ScalaJS.c.rx_core_Dynamic$().init___()
  };
  return ScalaJS.moduleInstances.rx_core_Dynamic
});
//@ sourceMappingURL=Dynamic$.js.map
